==> reshep-0.1.0.tgz: package/lib/__tests__/deep-merge.js <==
'use strict';

var _util = require('./../util');

describe('reshep > util > deepMerge', function () {
  test('Merges object sources.', function () {
    var a = { x: 1 };
    var b = { y: 2 };

    var result = (0, _util.deepMerge)(a, b);
    var expected = { x: 1, y: 2 };

    expect(result).toEqual(expected);
  });

  test('Overwrites non-object values at same path.', function () {
    var a = { x: 1 };
    var b = { x: 2 };

    var result = (0, _util.deepMerge)(a, b);
    var expected = { x: 2 };

    expect(result).toEqual(expected);
  });

  test('Gives merge precedence to right most source.', function () {
    var a = { x: { y: 1 } };
    var b = { x: 2 };

    expect((0, _util.deepMerge)(a, b)).toEqual(b);
    expect((0, _util.deepMerge)(b, a)).toEqual(a);
  });

  test('Merges nested objects.', function () {
    var a = { x: { y: 1 } };
    var b = { x: { z: 2 } };

    var result = (0, _util.deepMerge)(b, a);
    var expected = { x: { y: 1, z: 2 } };

    expect(result).toEqual(expected);
  });

  test('Deeply merges an arbitrary number of objects at arbitrary depths.', function () {
    var a = { x: 1, y: 2 };
    var b = { x: 1, y: { z: 2 } };
    var c = { z: 3 };
    var d = { x: { y: { z: 3 } } };

    var result = (0, _util.deepMerge)(a, b, c, d);
    var expected = { x: { y: { z: 3 } }, y: { z: 2 }, z: 3 };

    expect(result).toEqual(expected);
  });

  test('Does not deeply merge arrays.', function () {
    var a = { x: [true] };
    var b = { x: [false] };

    var result = (0, _util.deepMerge)(a, b);
    var expected = { x: [false] };

    expect(result).toEqual(expected);
  });
});

==> reshep-0.1.2.tgz: package/lib/__tests__/deep-merge.js <==
'use strict';

var _util = require('./../util');

describe('reshep > util > deepMerge', function () {
  test('Merges object sources.', function () {
    var a = { x: 1 };
    var b = { y: 2 };

    var result = (0, _util.deepMerge)(a, b);
    var expected = { x: 1, y: 2 };

    expect(result).toEqual(expected);
  });

  test('Overwrites non-object values at same path.', function () {
    var a = { x: 1 };
    var b = { x: 2 };

    var result = (0, _util.deepMerge)(a, b);
    var expected = { x: 2 };

    expect(result).toEqual(expected);
  });

  test('Gives merge precedence to right-most source.', function () {
    var a = { x: { y: 1 } };
    var b = { x: 2 };

    expect((0, _util.deepMerge)(a, b)).toEqual(b);
    expect((0, _util.deepMerge)(b, a)).toEqual(a);
  });

  test('Merges nested objects.', function () {
    var a = { x: { y: 1 } };
    var b = { x: { z: 2 } };

    var result = (0, _util.deepMerge)(b, a);
    var expected = { x: { y: 1, z: 2 } };

    expect(result).toEqual(expected);
  });

  test('Deeply merges an arbitrary number of objects at arbitrary depths.', function () {
    var a = { x: 1, y: 2 };
    var b = { x: 1, y: { z: 2 } };
    var c = { z: 3 };
    var d = { x: { y: { z: 3 } } };

    var result = (0, _util.deepMerge)(a, b, c, d);
    var expected = { x: { y: { z: 3 } }, y: { z: 2 }, z: 3 };

    expect(result).toEqual(expected);
  });

  test('Does not deeply merge arrays.', function () {
    var a = { x: [true] };
    var b = { x: [false] };

    var result = (0, _util.deepMerge)(a, b);
    var expected = { x: [false] };

    expect(result).toEqual(expected);
  });
});
